%define tarname	Sphinx
%define name	python-sphinx
%define version	1.1.3 
%define release	%mkrel 7

# disable these for bootstrapping nose and sphinx
%define enable_tests 1
%define enable_doc 1

Summary:	Python documentation generator
Name:		%{name}
Version:	%{version}
Release:	%{release}
Source0:	http://pypi.python.org/packages/source/S/%{tarname}/%{tarname}-%{version}.tar.gz
Patch0:		Sphinx-1.1.3-sagemath.patch
# https://bitbucket.org/birkenfeld/sphinx/commits/ffb145b7884fc926d6a68f4aaeede1d4964f727c
Patch1:		Sphinx-1.1.3-manpage-writer.patch
# Fixes quoting issue in inheritance_diagram.py
# Already applied upstream as part of https://bitbucket.org/birkenfeld/sphinx/commits/fc1db93d21a5a535d9d62e5a0c9f0a806a8c117a
Patch2:		Sphinx-1.1.3-fix_quoting_in_inheritance.patch

License:	BSD
Group:		Development/Python
Url:		http://sphinx.pocoo.org/
BuildArch:	noarch
Requires:	python-pkg-resources
Requires:	python-docutils >= 0.7
Requires:	python-pygments >= 1.2
Requires:	python-jinja2 >= 2.3
BuildRequires:	python-setuptools
Requires:	python-pygments >= 1.2
%if %enable_doc
BuildRequires:	python-docutils >= 0.7
BuildRequires:	python-jinja2 >= 2.3
%endif
%if %enable_tests
BuildRequires:	python-nose
BuildRequires:	python3-nose
%endif
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools


%description
Sphinx is a tool that facilitates the creation of beautiful
documentation for Python projects from reStructuredText sources. It
was originally created to format the new documentation for Python, but
has since been cleaned up in the hope that it will be useful in many
other projects.

%package -n python3-sphinx
Summary:	Python documentation generator
Group:		Development/Python
Requires:	python3-docutils
Requires:	python3-jinja2
Requires:	python3-pygments

%description -n python3-sphinx
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

%if %enable_doc
%package doc
Summary:	Documentation for %{name}
Group:		Documentation
License:	BSD
Requires:	%{name} = %{version}-%{release}

%description doc
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

This package contains documentation in reST and HTML formats.
%endif

%prep
%setup -q -n %{tarname}-%{version}
%patch0 -p1
%patch1 -p1 -b .manpage-writer
%patch2 -p1

rm -rf %{py3dir}
cp -a . %{py3dir}

%build
%{__python} setup.py build
pushd %{py3dir}
%{__python3} setup.py build
popd

%if %enable_doc
pushd doc
make html
make man
rm -rf _build/html/.buildinfo
mv _build/html ..
popd
%endif


%install
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
for f in %{buildroot}%{_bindir}/sphinx-*;
do
    mv $f $f-%{python3_version}
done
popd

%{__python} setup.py install --skip-build --root=%{buildroot} 

%if %enable_doc
pushd doc
# Deliver man pages
install -d %{buildroot}%{_mandir}/man1
mv _build/man/sphinx-*.1 %{buildroot}%{_mandir}/man1/
for f in %{buildroot}%{_mandir}/man1/sphinx-*.1;
do
    cp -p $f $(echo $f | sed -e "s|.1$|-%{python3_version}.1|")
done
popd

# Deliver rst files
rm -rf doc/_build
sed -i 's|python ../sphinx-build.py|/usr/bin/sphinx-build|' doc/Makefile
mv doc reST
%endif

# Move language files to /usr/share;
# patch to support this incorporated in 0.6.6
pushd %{buildroot}%{python_sitelib}

for lang in `find sphinx/locale -maxdepth 1 -mindepth 1 -type d -printf "%f "`;
do
  install -d %{buildroot}%{_datadir}/sphinx/locale/$lang
  install -d %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.js \
     %{buildroot}%{_datadir}/sphinx/locale/$lang/
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.mo \
    %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/
  rm -rf sphinx/locale/$lang
done
popd
%find_lang sphinx

# Language files; Since these are javascript, it's not immediately obvious to
# find_lang that they need to be marked with a language.
(cd %{buildroot} && find . -name 'sphinx.js') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.js$\):%lang(\2) \1\2\3:' \
  >> sphinx.lang


%check
%if %enable_tests
pushd tests
%__python run.py
popd
pushd %{py3dir}
make test
popd
%endif

%files -f sphinx.lang
%doc AUTHORS CHANGES EXAMPLES LICENSE README TODO
%exclude %{_bindir}/sphinx-*-%{python3_version}
%{_bindir}/sphinx-*
%{python_sitelib}/*
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale
%dir %{_datadir}/sphinx/locale/*
%exclude %{_mandir}/man1/sphinx-*-%{python3_version}.1*
%{_mandir}/man1/*

%files -n python3-sphinx
%doc AUTHORS CHANGES EXAMPLES LICENSE README TODO
%{_bindir}/sphinx-*-%{python3_version}
%{python3_sitelib}/*
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale
%dir %{_datadir}/sphinx/locale/*
%{_mandir}/man1/sphinx-*-%{python3_version}.1*

%if %enable_doc
%files doc
%defattr(-,root,root,-)
%doc html reST
%endif



%changelog
* Tue Oct 22 2013 umeabot <umeabot> 1.1.3-7.mga4
+ Revision: 544172
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.1.3-6.mga4
+ Revision: 499416
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 03 2013 philippem <philippem> 1.1.3-5.mga4
+ Revision: 449988
- Fixes quoting issue in inheritance_diagram.py

* Tue Jul 02 2013 philippem <philippem> 1.1.3-4.mga4
+ Revision: 449676
- add Python 3

* Wed Jan 23 2013 sander85 <sander85> 1.1.3-3.mga3
+ Revision: 391602
- Fix manpage writer in expectation of docutils 0.10 API change (upstream#998)

* Sun Jan 13 2013 umeabot <umeabot> 1.1.3-2.mga3
+ Revision: 379544
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 16 2012 philippem <philippem> 1.1.3-1.mga3
+ Revision: 294491
- New version 1.1.3

* Thu Nov 03 2011 lebedov <lebedov> 1.1.2-1.mga2
+ Revision: 162399
- Update to 1.1.2.

* Tue Oct 11 2011 lebedov <lebedov> 1.1-1.mga2
+ Revision: 153944
- Update to 1.1.

* Sat Sep 24 2011 fwang <fwang> 1.0.8-1.mga2
+ Revision: 147323
- new version 1.0.8

* Mon Feb 21 2011 ahmad <ahmad> 1.0.7-2.mga1
+ Revision: 55584
- rebuild to make all pythonegg requires/provides lowercase

* Thu Feb 03 2011 ahmad <ahmad> 1.0.7-1.mga1
+ Revision: 46761
- update to 1.0.7

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-7.mga1
+ Revision: 45405
- Enable back as python-nose have been rebuild

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-6.mga1
+ Revision: 45371
- Bump release
- bootstrap for rebuild gainst

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.5-5.mga1
+ Revision: 45350
- bootstrap because we need to rebuild python-nose
- Rebuild against python 2.7

  + pterjan <pterjan>
    - Re-enable tests

* Mon Jan 17 2011 pterjan <pterjan> 1.0.5-4.mga1
+ Revision: 21282
- Enable bootstrap
- Rebuild for python 2.7

* Thu Jan 13 2011 ahmad <ahmad> 1.0.5-3.mga1
+ Revision: 8372
- enable doc and tests

* Thu Jan 13 2011 ahmad <ahmad> 1.0.5-2.mga1
+ Revision: 8357
- disable doc and tests for now
- replace deprecated %%py_requires macro with BR python-devel
- imported package python-sphinx


* Fri Nov 12 2010 Lev Givon <lev@mandriva.org> 1.0.5-1mdv2011.0
+ Revision: 596694
- Update to 1.0.5.

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 1.0.4-3mdv2011.0
+ Revision: 590417
- reenable test and documentation, now that requirement are here

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 1.0.4-2mdv2011.0
+ Revision: 590369
- also fix the documentation generation ( bootstraping problem, since jinja2 requires sphinx too )
- disable test ( as nose requires sphinx, and sphinx requires nose, they cannot be upgraded to 2.7 )
- rebuild for python 2.7

* Fri Sep 17 2010 Lev Givon <lev@mandriva.org> 1.0.4-1mdv2011.0
+ Revision: 579194
- Update to 1.0.4.

* Wed Sep 15 2010 Lev Givon <lev@mandriva.org> 1.0.3-1mdv2011.0
+ Revision: 578780
- Update to 1.0.3.

* Tue Jul 27 2010 Lev Givon <lev@mandriva.org> 0.6.7-1mdv2011.0
+ Revision: 562106
- Update to 0.6.7.
- Update to 0.6.6.

* Thu Mar 11 2010 Lev Givon <lev@mandriva.org> 0.6.5-1mdv2010.1
+ Revision: 518262
- Update to 0.6.5.

* Wed Jan 13 2010 Lev Givon <lev@mandriva.org> 0.6.4-1mdv2010.1
+ Revision: 491048
- Update to 0.6.4.

* Tue Sep 08 2009 Lev Givon <lev@mandriva.org> 0.6.3-1mdv2010.0
+ Revision: 433689
- Update to 0.6.3.
  Build docs as html.

* Wed Aug 05 2009 Paulo Andrade <pcpa@mandriva.com.br> 0.6.2-2mdv2010.0
+ Revision: 409716
- Add sagemath patch to python-sphinx.

* Wed Jun 17 2009 Lev Givon <lev@mandriva.org> 0.6.2-1mdv2010.0
+ Revision: 386763
- Update to 0.6.2.

* Fri May 22 2009 Lev Givon <lev@mandriva.org> 0.6.1-1mdv2010.0
+ Revision: 378621
- Update to 0.6.1.

* Mon May 04 2009 Lev Givon <lev@mandriva.org> 0.5.2-2mdv2010.0
+ Revision: 371821
- Fix requirements.

* Tue Mar 24 2009 Lev Givon <lev@mandriva.org> 0.5.2-1mdv2010.0
+ Revision: 360951
- Update to 0.5.2.
  Change python-setuptools install requirement to python-pkg-resources.

* Sun Jan 04 2009 Jérôme Soyer <saispo@mandriva.org> 0.5.1-1mdv2009.1
+ Revision: 324276
- New upstream release

* Sun Dec 28 2008 Funda Wang <fwang@mandriva.org> 0.5-2mdv2009.1
+ Revision: 320265
- rebuild for new python

* Tue Dec 02 2008 Lev Givon <lev@mandriva.org> 0.5-1mdv2009.1
+ Revision: 308946
- Update to 0.5.

* Sun Oct 19 2008 Lev Givon <lev@mandriva.org> 0.4.3-1mdv2009.1
+ Revision: 295422
- Update to 0.4.3.

* Wed Aug 06 2008 Lev Givon <lev@mandriva.org> 0.4.2-2mdv2009.0
+ Revision: 264333
- Add setuptools as an install requirement
  (pkg_resources needed by sphinx-build).

* Wed Aug 06 2008 Lev Givon <lev@mandriva.org> 0.4.2-1mdv2009.0
+ Revision: 264111
- Update to 0.4.2.

* Fri Jul 11 2008 Lev Givon <lev@mandriva.org> 0.4.1-1mdv2009.0
+ Revision: 233844
- Update to 0.4.1.

* Mon Jun 23 2008 Lev Givon <lev@mandriva.org> 0.4-1mdv2009.0
+ Revision: 228282
- Update to 0.4.

* Fri May 30 2008 Lev Givon <lev@mandriva.org> 0.3-1mdv2009.0
+ Revision: 213482
- import python-sphinx


* Thu May 29 2008 Lev Givon <lev@mandriva.org> 0.3-1mdv2008.1
- Package for Mandriva.
